@@ -38,7 +38,13 @@ protected:
     void timerEvent(QTimerEvent *event) override;
 
 private:
-    enum { None, Selecting, Deselecting, Blinking, BlinkingExiting } m_status;
+    enum {
+        None,
+        Selecting,
+        Deselecting,
+        Blinking,
+        BlinkingExiting
+    } m_status;
     QModelIndex m_index;
 
     int m_timerId;
